@@ -101,7 +101,7 @@ function tw_google_language_tools
 	TW_TERM="$2"
 	curl -s -A "Mozilla/5.0" -d "hl=en" -d "ie=UTF8" -d "text=${TW_TERM}" \
 	-d "langpair=${TW_LANGUAGE}" http://translate.google.com/translate_t | \
-	grep 'id=result_box' | cut -d'>' -f55 | cut -d'<' -f1 
+	grep "gtrans" | gawk -F"gtrans" '{print $2}' | cut -d'"' -f2
 }
 
 function tw_ls_dictionaries_google_language_tools
